@@ -1,7 +1,7 @@
 """
 Type annotations for ssm service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/literals/)
 
 Usage::
 
@@ -150,9 +150,12 @@ __all__ = (
     "SignalTypeType",
     "StepExecutionFilterKeyType",
     "StopTypeType",
+    "SSMServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
+    "RegionName",
 )
 
 
@@ -498,6 +501,7 @@ StepExecutionFilterKeyType = Literal[
     "StepName",
 ]
 StopTypeType = Literal["Cancel", "Complete"]
+SSMServiceName = Literal["ssm"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -531,6 +535,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -785,6 +790,18 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_activations",
     "describe_association_execution_targets",
@@ -834,3 +851,26 @@ PaginatorName = Literal[
     "list_resource_data_sync",
 ]
 WaiterName = Literal["command_executed"]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
